@@ -151,7 +151,7 @@ C<XDEBUG_SESSION> cookie.
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use constant {
     DEBUG_SINGLE_STEP_ON        =>  0x20,
@@ -255,7 +255,8 @@ EOT
         Enbugger->load_source;
     }
 
-    unshift @INC, $args{debug_client_path};
+    my $inc_path = $args{debug_client_path};
+    unshift @INC, ref $inc_path ? @$inc_path : $inc_path;
     {
         local $SIG{__WARN__} = \&_trap_connection_warnings;
         require 'perl5db.pl';
@@ -358,7 +359,7 @@ Mattia Barbon <mbarbon@cpan.org>
 
 =head1 LICENSE
 
-Copyright (c) 2015 Mattia Barbon. All rights reserved.
+Copyright (c) 2015-2016 Mattia Barbon. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
